@@ -9,6 +9,7 @@ from kpler.sdk.helpers import (
     process_bool_parameter,
     process_date_parameter,
     process_enum_parameter,
+    process_enum_parameters,
     process_list_parameter,
 )
 
@@ -40,6 +41,8 @@ class FleetMetrics(KplerClient):
         unit: Optional[Enum] = None,
         split: Optional[Enum] = None,
         with_freight_view: bool = False,
+        vessel_types: Optional[List[str]] = None,
+        vessel_types_alt: Optional[List[str]] = None,
     ):
 
         """
@@ -55,6 +58,8 @@ class FleetMetrics(KplerClient):
             unit: Optional[Enum] ``FleetMetricsMeasurementUnit`` by default return in bbl unit or cm on LNG platform
             split: Optional[Enum] ``FleetMetricsSplit``
             with_freight_view: bool By default: with_freight_view=False. Provides access to the entire fleet's trades, irrespective of your current cargo subscription. Only available via Freight subscription.
+            vessel_types: Optional[List[str]] = Names of vessel types
+            vessel_types_alt: Optional[List[str]] = Names of vessel types for oil liquids platform only
 
         Examples:
 
@@ -91,5 +96,7 @@ class FleetMetrics(KplerClient):
             "unit": process_enum_parameter(unit),
             "split": process_enum_parameter(split),
             "withFreightView": process_bool_parameter(with_freight_view),
+            "vesselTypes": process_enum_parameters(vessel_types, to_lower_case=False),
+            "vesselTypesAlt": process_enum_parameters(vessel_types_alt, to_lower_case=False),
         }
         return self._get_dataframe(self.RESOURCE_NAME, query_parameters)
